@@ -45,12 +45,21 @@ class Execution:
             if not os.path.exists(cmd[option_start - 1]):
                 raise FileNotFoundError("Script %s not found" % cmd[option_start - 1])
 
-            cmd = (
-                cmd[:option_start]
-                + [identifier]
-                + self.execution_file.get_std_args()
-                + cmd[option_start:]
-            )
+            # if legacy flag is set we need to add the identifier as the first argument
+            if options.legacy:
+                cmd = (
+                    cmd[:option_start]
+                    + [identifier]
+                    + self.execution_file.get_std_args()
+                    + cmd[option_start:]
+                )
+            else:
+                cmd = (
+                    cmd[:option_start]
+                    + self.execution_file.get_std_args()
+                    + cmd[option_start:]
+                )
+
             cmd = " ".join(cmd)
 
             start = time.time()
@@ -59,16 +68,33 @@ class Execution:
                 "STDOUT and STDERR will be written to %s.",
                 "log files" if options.log else "console",
             )
+
+            # check if we are logging
             if options.log:
+                # process = multiprocessing.Process(target=self.execute_one, args=(cmd, True, ex))
                 with ex.open_log_files() as (f_stdout, f_stderr):
-                    completed_process = subprocess.run(
+                    process = subprocess.Popen(
                         cmd, stdout=f_stdout, stderr=f_stderr, shell=True
                     )
             else:
-                completed_process = subprocess.run(cmd, shell=True)
+                # process = multiprocessing.Process(target=self.execute_one, args=(cmd, False,))
+                process = subprocess.Popen(cmd, shell=True)
+
+            # start the process then create the correct pid_file and then join
+            # process.start()
+            # for some reason the pid is always 1 too low
+            pid = None if process.pid == None else process.pid
+            pid_path = self.get_pid_file_path(pid)
+
+            # create the file containing the correct path
+            with open(pid_path, "w") as f:
+                f.write(str(ex.path_to_experiment))
+                f.close()
+            
+            process.wait()
             end = time.time()
 
-            if completed_process.returncode == 0:
+            if process.returncode == 0:
                 logging.info(
                     "Sucessfully finished job Nr. %d %s in %.2f seconds"
                     % (current_job, identifier, (end - start))
@@ -80,7 +106,7 @@ class Execution:
                         identifier,
                         current_job,
                         (end - start),
-                        completed_process.returncode,
+                        process.returncode,
                     )
                 )
                 if options.log:
@@ -95,8 +121,22 @@ class Execution:
             if self.debug:
                 ex.erase()
 
+    def get_pid_file_path(self, pid) -> str:
+        return ".hermes_pids/%d" % pid
+
+    def execute_one(self, cmd, logging=False, ex=None):
+        p = None
+        if not logging:
+            p = subprocess.Popen(cmd, shell=True)
+        elif(ex != None):
+            with ex.open_log_files() as (f_stdout, f_stderr):
+                p = subprocess.Popen(
+                    cmd, stdout=f_stdout, stderr=f_stderr, shell=True
+                )
+
+        return p
+
     def run(self):
-        start = time.time()
         threads = [
             threading.Thread(target=self.worker, args=[i])
             for i in range(self.num_threads)
@@ -109,8 +149,6 @@ class Execution:
         for t in threads:
             t.join()
 
-        end = time.time()
-
     def __init__(self, execution_file, experiment_name=None, debug=False):
         self.execution_file = execution_file
         self.jobs = execution_file.executions
