@@ -1,5 +1,6 @@
 import re
 import itertools
+import numpy as np
 from collections import deque
 from typing import List, Tuple
 
@@ -15,7 +16,7 @@ def _parse_list(lst_str):
     return contents
 
 
-_kwarg_pattern = re.compile("([^(=|,|\(|\))]+)=(\[[^(=|\(|\))]+\])")
+_kwarg_pattern = re.compile("([^(=|,|\(|\))]+)=(RANGE)?(\[[^(=|\(|\))]+\])")
 _exec_line_pattern = re.compile("^\[\[.*\],\[.*\]\]$")
 _directive_pattern = re.compile("^[a-zA-Z]+\(.*\)")
 
@@ -137,6 +138,27 @@ class Directive(Expression):
     def resolve(self):
         raise NotImplementedError()
 
+    def calculateRange(self, constrains):
+        # check if we need to parse the functions as a float or int
+        range_function, parse_function = (np.arange, float) if ("." in constrains) else (range, int)
+        # parse string to array of strings 
+        constrains = constrains.replace("[", "").replace("]", "").split(",")
+        assert len(constrains) == 3, "A RANGE list must always be of length 3"
+        # parse constrains string to integers
+        try:
+            constrains = [parse_function(val) for val in constrains]
+        except ValueError:
+            assert False, "Range can only handle Numbers"
+
+
+        start = constrains[0]
+        end = constrains[1]
+        step = constrains[2]
+        # test if range is finite
+        assert abs(end - (start + step)) < abs((end - start)), "Range cannot be infinite"
+
+        return str([(val) for val in range_function(start, end, step)])
+
     def initial_parse(self, exec_line):
 
         kwargs = [_kwarg_pattern.match(itm) for itm in self.contents]
@@ -144,7 +166,8 @@ class Directive(Expression):
         args = [self.contents[i] for i, kwarg in enumerate(kwargs) if kwarg is None]
         assert len(args) >= 1
 
-        kwargs = [(itm.group(1), itm.group(2)) for itm in kwargs if itm is not None]
+        # itm.group(2) is the "modifier", i.e. RANGE or None
+        kwargs = [(itm.group(1),  self.calculateRange(itm.group(3)) if itm.group(2) == "RANGE" else itm.group(3)) for itm in kwargs if itm is not None]
         kwargs = {key.lstrip().rstrip(): _parse_list(val) for key, val in kwargs}
         return args, kwargs
 
@@ -199,7 +222,6 @@ class Prod(Directive):
         del self.contents
         return lines, True
 
-
 class InlineComment(Expression):
     def __init__(self, flags: List[str] = ["#", "//"]):
         super().__init__()
@@ -253,12 +275,26 @@ if __name__ == "__main__":
     lines, _ = ZIP.resolve(test)
     [print("ZIP", line) for line in lines]
 
+    test = "ZIP([[./test.py, -alpha {a}, -beta {b}],[-ca test.py]], a=RANGE[-5, 0, 1], b=RANGE[2.5, 5, 0.5])"
+    ZIP = Zip()
+    assert ZIP.match(test)
+    lines, _ = ZIP.resolve(test)
+    print("ZIP with RANGE")
+    [print("ZIP", line) for line in lines]
+
     test = "PROD([[./test.py, -alpha {a}, -beta {b}],[-ca test.py]], a=[0.05, 0.01, 0.1], b=[100, 500])"
     PROD = Prod()
     assert PROD.match(test)
     lines, _ = PROD.resolve(test)
     [print("PROD", line) for line in lines]
 
+    test = "PROD([[./test.py, -alpha {a}, -beta {b}],[-ca test.py]], a=RANGE[0.05, 0.01, -0.01], b=RANGE[0,2,1])"
+    PROD = Prod()
+    assert PROD.match(test)
+    lines, _ = PROD.resolve(test)
+    print("PROD with RANGE")
+    [print("PROD", line) for line in lines]
+
     test = "ZIP([[./test.py, -a {a}, -b {b}],[-ca test.py]], [[./foo.py, -a {a}, -b {b}],[-ca foo.py]], a=[0.05, 0.01], b=[100, 500])"
     test = "ZIP(PROD([[./test.py, -a {a}, -b {b} --seed {seed}],[-ca test.py]], [[./foo.py, -a {a}, -b {b}, --seed {seed}],[-ca foo.py]], a=[0.05, 0.01], b=[100, 500]), seed=[0,1,2])"
     assert ZIP.match(test)
