@@ -114,6 +114,12 @@ class Experiment:
         settings = execution_file.settings
         commit_hash = get_current_commit_hash()
 
+        # check if .hermes_pids exists, if not make it
+        path_to_pids = (".hermes_pids")
+        if not os.path.exists(path_to_pids):
+            logging.info("Creating new directory %s" % path_to_pids)
+            os.mkdir(path_to_pids)
+
         # check if experiments directory exists, if not make it
         path_to_experiments = Path(settings["path_to_experiments"])
         path_to_experiments = path_to_experiments.joinpath("experiments")
@@ -273,7 +279,6 @@ class Experiment:
                     except:
                         val = str(val)
                 elif len(aux) > 2:
-                    logging.warning("Unknown exec argument format: %s" % arg)
                     key = aux[0]
                     vals = aux[1:]
                     try:
@@ -283,6 +288,9 @@ class Experiment:
                             val = [float(val) for val in vals]
                         except:
                             val = [str(val) for val in vals]
+                            logging.warning(
+                                f"Unknown exec argument format '{arg}' was parsed as ({key}: {val})"
+                            )
                 if key in self._exec_args_dict:
                     try:
                         self._exec_args_dict[key].append(val)
@@ -413,8 +421,6 @@ class Experiment:
                 pass
 
             for possible_path in possible_paths:
-                print(possible_path)
-
                 try:
                     network_module = importlib.import_module(possible_path.stem)
                     network_classes[key] = network_module.Network
@@ -656,9 +662,7 @@ class Experiment:
         self._add_to_info(
             Experiment.START_TIME_N, start_time.strftime(Experiment.TIME_FMT)
         )
-        self._add_to_info(
-            Experiment.END_TIME_N, end_time.strftime(Experiment.TIME_FMT)
-        )
+        self._add_to_info(Experiment.END_TIME_N, end_time.strftime(Experiment.TIME_FMT))
         self._add_to_info(Experiment.EXECUTION_TIME_N, str(execution_time))
 
     def _fetch_new_files(self):
@@ -793,7 +797,6 @@ if _is_loaded("pandas") or _is_loaded("pd"):
                     for exp in experiments
                 ]
 
-
 else:
 
     class _ExperimentFrame:
