@@ -25,7 +25,7 @@ def load_network_class_from_experiment_directory(
     """
 
     def _correct_path(path):
-        slash = '\\' if os.name == 'nt' else '/'
+        slash = "\\" if os.name == "nt" else "/"
         if not path.endswith(slash):
             path += slash
 
@@ -257,3 +257,26 @@ def save_namespace(namespace, name):
     """
     d = vars(namespace)
     save_dict(d, name)
+
+
+class ScoreWindow:
+    def __init__(self, window_size=100):
+        self.window_size = window_size
+        self.num = 0
+        self.id = 0
+        self.window = np.zeros(self.window_size)
+
+    def append(self, element):
+        if self.num < self.window_size:
+            self.window[self.id] = element
+            self.num += 1
+        else:
+            self.window[self.id] = element
+        self.id = (self.id + 1) % self.window_size
+
+    def mean(self):
+        assert self.num != 0, "There must be at least one element to define the mean"
+        return np.mean(self.window[: self.num])
+
+    def __iter__(self):
+        return self.window.__iter__()
